import React from 'react';
import PropTypes from 'prop-types';
import * as reset from '../reset';
import { noWrap } from '../utils';

export const BodyComponent = reset.p`
  font-family: ${p => p.theme.text.body.fontFamily};
  font-size: ${p => p.theme.text.body.fontSize}px;
  line-height: ${p => p.theme.text.body.lineHeight}px;
  padding-top: ${p => p.theme.text.body.paddingTop}px;
  padding-bottom: ${p => p.theme.text.body.paddingBottom}px;
  color: ${p => p.theme.text.body.color};
  ${props => props.align && `text-align: ${props.align};`};
  ${props => props.noWrap && noWrap};
`;

const Body = props => React.createElement(BodyComponent, props);

Body.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Set the text-align on the component.
   */
  align: PropTypes.oneOf(['inherit', 'left', 'center', 'right', 'justify']),
  /**
   * The content of the component.
   */
  children: PropTypes.node,
  /**
   * The content of the component.
   */
  color: PropTypes.string,
  /**
   * The content of the component.
   */
  gutterBottom: PropTypes.bool,
  /**
   * If `true`, the text will not wrap, but instead will truncate with an ellipsis.
   */
  noWrap: PropTypes.bool
} : {};

Body.defaultProps = {
  align: 'inherit',
  color: 'default',
  gutterBottom: false,
  noWrap: false
};

export default Body;